@@ -30,9 +30,11 @@ import mimetypes
 import os
 
 from mutagen import File
+from mutagen.easyid3 import EasyID3
+from mutagen.easymp4 import EasyMP4Tags
 from mutagen.flac import Picture
 from mutagen.id3 import APIC, ID3
-from mutagen.mp3 import MP3
+from mutagen.mp3 import MP3, EasyMP3
 from mutagen.mp4 import MP4Cover, MP4Tags
 
 import gpodder
@@ -61,14 +63,17 @@ DefaultConfig = {
     'always_remove_tags': False,
     'auto_embed_coverart': False,
     'set_artist_to_album': False,
+    'set_version': 4,
+    'modify_tags': True
 }
 
 
 class AudioFile(object):
-    def __init__(self, filename, album, title, genre, pubDate, cover):
+    def __init__(self, filename, album, title, subtitle, genre, pubDate, cover):
         self.filename = filename
         self.album = album
         self.title = title
+        self.subtitle = subtitle
         self.genre = genre
         self.pubDate = pubDate
         self.cover = cover
@@ -79,28 +84,39 @@ class AudioFile(object):
             audio.delete()
         audio.save()
 
-    def write_basic_tags(self, set_artist_to_album):
+    def write_basic_tags(self, modify_tags, set_artist_to_album, set_version):
         audio = File(self.filename, easy=True)
 
         if audio.tags is None:
             audio.add_tags()
 
-        if self.album is not None:
-            audio.tags['album'] = self.album
+        if modify_tags:
+            if self.album is not None:
+                audio.tags['album'] = self.album
 
-        if self.title is not None:
-            audio.tags['title'] = self.title
+            if self.title is not None:
+                audio.tags['title'] = self.title
 
-        if self.genre is not None:
-            audio.tags['genre'] = self.genre
+            if self.subtitle is not None:
+                audio.tags['subtitle'] = self.subtitle
 
-        if self.pubDate is not None:
-            audio.tags['date'] = self.pubDate
+            if self.subtitle is not None:
+                audio.tags['comments'] = self.subtitle
 
-        if set_artist_to_album:
-            audio.tags['artist'] = self.album
+            if self.genre is not None:
+                audio.tags['genre'] = self.genre
 
-        audio.save()
+            if self.pubDate is not None:
+                audio.tags['date'] = self.pubDate
+
+            if set_artist_to_album:
+                audio.tags['artist'] = self.album
+
+        if type(audio) is EasyMP3:
+            audio.save(v2_version=set_version)
+        else:
+            # Not actually audio
+            audio.save()
 
     def insert_coverart(self):
         """ implement the cover art logic in the subclass
@@ -125,8 +141,8 @@ class AudioFile(object):
 
 
 class OggFile(AudioFile):
-    def __init__(self, filename, album, title, genre, pubDate, cover):
-        super(OggFile, self).__init__(filename, album, title, genre, pubDate, cover)
+    def __init__(self, filename, album, title, subtitle, genre, pubDate, cover):
+        super(OggFile, self).__init__(filename, album, title, subtitle, genre, pubDate, cover)
 
     def insert_coverart(self):
         audio = File(self.filename, easy=True)
@@ -136,8 +152,8 @@ class OggFile(AudioFile):
 
 
 class Mp4File(AudioFile):
-    def __init__(self, filename, album, title, genre, pubDate, cover):
-        super(Mp4File, self).__init__(filename, album, title, genre, pubDate, cover)
+    def __init__(self, filename, album, title, subtitle, genre, pubDate, cover):
+        super(Mp4File, self).__init__(filename, album, title, subtitle, genre, pubDate, cover)
 
     def insert_coverart(self):
         audio = File(self.filename)
@@ -153,8 +169,8 @@ class Mp4File(AudioFile):
 
 
 class Mp3File(AudioFile):
-    def __init__(self, filename, album, title, genre, pubDate, cover):
-        super(Mp3File, self).__init__(filename, album, title, genre, pubDate, cover)
+    def __init__(self, filename, album, title, subtitle, genre, pubDate, cover):
+        super(Mp3File, self).__init__(filename, album, title, subtitle, genre, pubDate, cover)
 
     def insert_coverart(self):
         audio = MP3(self.filename, ID3=ID3)
@@ -177,6 +193,11 @@ class Mp3File(AudioFile):
 class gPodderExtension:
     def __init__(self, container):
         self.container = container
+        # fix #737 EasyID3 doesn't recognize subtitle and comment tags
+        EasyID3.RegisterTextKey("comments", "COMM")
+        EasyID3.RegisterTextKey("subtitle", "TIT3")
+        EasyMP4Tags.RegisterTextKey("comments", "desc")
+        EasyMP4Tags.RegisterFreeformKey("subtitle", "SUBTITLE")
 
     def on_episode_downloaded(self, episode):
         info = self.read_episode_info(episode)
@@ -207,6 +228,7 @@ class gPodderExtension:
             audio = audioClass(info['filename'],
                 info['album'],
                 info['title'],
+                info['subtitle'],
                 info['genre'],
                 info['pubDate'],
                 cover)
@@ -217,6 +239,7 @@ class gPodderExtension:
             'filename': None,
             'album': None,
             'title': None,
+            'subtitle': None,
             'genre': None,
             'pubDate': None
         }
@@ -234,6 +257,8 @@ class gPodderExtension:
         else:
             info['title'] = title
 
+        info['subtitle'] = episode.description
+
         if self.container.config.genre_tag is not None:
             info['genre'] = self.container.config.genre_tag
 
@@ -257,7 +282,9 @@ class gPodderExtension:
         if self.container.config.always_remove_tags:
             audio.remove_tags()
         else:
-            audio.write_basic_tags(self.container.config.set_artist_to_album)
+            audio.write_basic_tags(self.container.config.modify_tags,
+                                   self.container.config.set_artist_to_album,
+                                   self.container.config.set_version)
 
             if self.container.config.auto_embed_coverart:
                 audio.insert_coverart()
