@@ -24,24 +24,28 @@
 #  Thomas Perl <thp@gpodder.org>; 2010-01-19
 #
 
-import gpodder
-_ = gpodder.gettext
-
 import atexit
-import datetime
 import calendar
+import datetime
+import logging
 import os
 import sys
 import time
 
-import logging
-logger = logging.getLogger(__name__)
-
-from gpodder import util
-from gpodder import minidb
-
 # Append gPodder's user agent to mygpoclient's user agent
 import mygpoclient
+from mygpoclient import api, public
+from mygpoclient import util as mygpoutil
+
+import gpodder
+from gpodder import minidb, util
+
+_ = gpodder.gettext
+
+
+logger = logging.getLogger(__name__)
+
+
 mygpoclient.user_agent += ' ' + gpodder.user_agent
 
 # 2013-02-08: We should update this to 1.7 once we use the new features
@@ -67,11 +71,6 @@ except ImportError:
     MissingCredentials = object()
 
 
-from mygpoclient import api
-from mygpoclient import public
-
-from mygpoclient import util as mygpoutil
-
 EPISODE_ACTIONS_BATCH_SIZE = 100
 
 
@@ -490,8 +489,8 @@ class MygPoClient(object):
         try:
             # Load the "since" value from the database
             since_o = self._store.get(SinceValue, host=self.host,
-                                                  device_id=self.device_id,
-                                                  category=SinceValue.EPISODES)
+                                      device_id=self.device_id,
+                                      category=SinceValue.EPISODES)
 
             # Use a default since object for the first-time case
             if since_o is None:
@@ -548,8 +547,8 @@ class MygPoClient(object):
         try:
             # Load the "since" value from the database
             since_o = self._store.get(SinceValue, host=self.host,
-                                                  device_id=self.device_id,
-                                                  category=SinceValue.PODCASTS)
+                                      device_id=self.device_id,
+                                      category=SinceValue.PODCASTS)
 
             # Use a default since object for the first-time case
             if since_o is None:
